@@ -797,7 +797,7 @@ class DMsddm(DisplayManager):
         import configparser
 
         # Systems with Sddm as Desktop Manager
-        sddm_conf_path = os.path.join(self.root_mount_point, "etc/sddm.conf")
+        sddm_conf_path = os.path.join(self.root_mount_point, "etc/sddm.conf.d/kde_settings.conf")
 
         sddm_config = configparser.ConfigParser(strict=False)
         # Make everything case sensitive
@@ -895,7 +895,8 @@ class DMgreetd(DisplayManager):
 
     def desktop_environment_setup(self, default_desktop_environment):
         with open(self.environments_path(), 'w') as envs_file:
-            envs_file.write(default_desktop_environment)
+            envs_file.write(default_desktop_environment.desktop_file)
+            envs_file.write("\n")
 
     def greeter_setup(self):
         pass
